@@ -58,7 +58,7 @@ setupLambda.gBridge <- function(X, y, group, family, alpha, lambda.min, lambda.m
       z <- crossprod(X[,ind], fit$weights * residuals(fit, "working")) / n
       a <- .2
     }
-    lambda.max <- max(abs(z)/group.multiplier)*a^(1-gamma)/(gamma*alpha)
+    lambda.max <- max(abs(z)/group.multiplier[group])*a^(1-gamma)/(gamma*alpha)
   }
   if (lambda.min==0) {
     lambda <- c(exp(seq(log(lambda.max), log(.001*lambda.max), len=nlambda-1)),0)
